/*
 * Copyright 2011 Nathan Dolan. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted provided that the following conditions are met:
 * 
 *    1. Redistributions of source code must retain the above copyright notice, this 
 *    list of conditions and the following disclaimer.
 *    2. Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation and/or 
 *    other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER ``AS IS'' AND ANY EXPRESS OR 
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO 
 * EVENT SHALL THE COPYRIGHT HOLDER BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 * SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR 
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 * 
 */
package com.sureassert.uc.tutorial.data;

import java.io.PrintWriter;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.SQLFeatureNotSupportedException;
import java.util.logging.Logger;

import javax.sql.DataSource;

import org.sureassert.uc.annotation.IgnoreTestCoverage;

/**
 * A DataSource for a non-existent database, for the purposes of the tutorial,
 * to avoid pulling in dependencies on a real database driver.
 */
@IgnoreTestCoverage
public class AcmeDatabaseDataSource implements DataSource {

	public PrintWriter getLogWriter() throws SQLException {
		// In our unit-test context, there will be no database to connect
		// to, so if we hit this method we'd end up getting something like this...
		throw new SQLException("Couldn't connect to Acme Database");
	}

	public int getLoginTimeout() throws SQLException {
		// In our unit-test context, there will be no database to connect
		// to, so if we hit this method we'd end up getting something like this...
		throw new SQLException("Couldn't connect to Acme Database");
	}

	public void setLogWriter(PrintWriter out) throws SQLException {
		// In our unit-test context, there will be no database to connect
		// to, so if we hit this method we'd end up getting something like this...
		throw new SQLException("Couldn't connect to Acme Database");
	}

	public void setLoginTimeout(int seconds) throws SQLException {
		// In our unit-test context, there will be no database to connect
		// to, so if we hit this method we'd end up getting something like this...
		throw new SQLException("Couldn't connect to Acme Database");
	}

	public boolean isWrapperFor(Class<?> iface) throws SQLException {
		// In our unit-test context, there will be no database to connect
		// to, so if we hit this method we'd end up getting something like this...
		throw new SQLException("Couldn't connect to Acme Database");
	}

	public <T> T unwrap(Class<T> iface) throws SQLException {
		// In our unit-test context, there will be no database to connect
		// to, so if we hit this method we'd end up getting something like this...
		throw new SQLException("Couldn't connect to Acme Database");
	}

	public Connection getConnection() throws SQLException {
		// In our unit-test context, there will be no database to connect
		// to, so if we hit this method we'd end up getting something like this...
		throw new SQLException("Couldn't connect to Acme Database");
	}

	public Connection getConnection(String username, String password)
			throws SQLException {
		// In our unit-test context, there will be no database to connect
		// to, so if we hit this method we'd end up getting something like this...
		throw new SQLException("Couldn't connect to Acme Database");
	}

	public Logger getParentLogger() throws SQLFeatureNotSupportedException {
		// TODO Auto-generated method stub
		return null;
	}
}
